==> green-core-1.70.1.tgz: package/primitives/selection-controls/selection-field-label.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { localized } from "@lit/localize";
import { property } from "lit/decorators.js";
import { classMap } from "lit/directives/class-map.js";
import { GdsElement } from "../../gds-element";
import { gdsCustomElement, html } from "../../scoping";
import { tokens } from "../../tokens.style";
import { TransitionalStyles } from "../../transitional-styles";
import { styles } from "./selection-field-label.styles";
let GdsSelectionFieldLabel = class extends GdsElement {
  constructor() {
    super();
    this.label = "";
    this.supportingText = "";
  }
  connectedCallback() {
    super.connectedCallback();
    TransitionalStyles.instance.apply(this, "gds-selection-field-label");
  }
  render() {
    const classes = {
      "selection-field-label": true,
      "has-supporting-text": !!this.supportingText
    };
    return html`
      <div class="selection-field-container">
        <div class="control-slot">
          <slot></slot>
        </div>
        <div class="${classMap(classes)}">
          <label class="primary-label"> ${this.label} </label>
          ${this.label ? html`
                <span class="supporting-text"> ${this.supportingText} </span>
              ` : ""}
        </div>
      </div>
    `;
  }
};
GdsSelectionFieldLabel.styles = [tokens, styles];
__decorateClass([
  property()
], GdsSelectionFieldLabel.prototype, "label", 2);
__decorateClass([
  property({ attribute: "supporting-text" })
], GdsSelectionFieldLabel.prototype, "supportingText", 2);
GdsSelectionFieldLabel = __decorateClass([
  gdsCustomElement("gds-selection-field-label"),
  localized()
], GdsSelectionFieldLabel);
export {
  GdsSelectionFieldLabel
};

==> green-core-1.71.0.tgz: package/primitives/selection-controls/selection-field-label.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { localized } from "@lit/localize";
import { property } from "lit/decorators.js";
import { classMap } from "lit/directives/class-map.js";
import { GdsElement } from "../../gds-element.js";
import { gdsCustomElement, html } from "../../scoping.js";
import { tokens } from "../../tokens.style";
import { TransitionalStyles } from "../../transitional-styles.js";
import { styles } from "./selection-field-label.styles";
let GdsSelectionFieldLabel = class extends GdsElement {
  constructor() {
    super();
    this.label = "";
    this.supportingText = "";
  }
  connectedCallback() {
    super.connectedCallback();
    TransitionalStyles.instance.apply(this, "gds-selection-field-label");
  }
  render() {
    const classes = {
      "selection-field-label": true,
      "has-supporting-text": !!this.supportingText
    };
    return html`
      <div class="selection-field-container">
        <div class="control-slot">
          <slot></slot>
        </div>
        <div class="${classMap(classes)}">
          <label class="primary-label"> ${this.label} </label>
          ${this.label ? html`
                <span class="supporting-text"> ${this.supportingText} </span>
              ` : ""}
        </div>
      </div>
    `;
  }
};
GdsSelectionFieldLabel.styles = [tokens, styles];
__decorateClass([
  property()
], GdsSelectionFieldLabel.prototype, "label", 2);
__decorateClass([
  property({ attribute: "supporting-text" })
], GdsSelectionFieldLabel.prototype, "supportingText", 2);
GdsSelectionFieldLabel = __decorateClass([
  gdsCustomElement("gds-selection-field-label"),
  localized()
], GdsSelectionFieldLabel);
export {
  GdsSelectionFieldLabel
};
